# Satellite Frequency Bands

Blockstream Satellite operates in Ku high band, Ku low band and C band,
depending on region. Ku high band is used in North America and South America. Ku
low band is used in Africa and Europe. C band is used in Asia-Pacific region.

| Band         | Frequency Range   |
|--------------|-------------------|
| C band       | 3.7 GHZ - 4.2 GHz |
| Ku low band  | 10.7 to 11.7 GHz  |
| Ku high band | 11.7 to 12.75 GHz |

You can always use antennas designed for higher frequencies. For example, an
antenna designed for Ka band will work for Ku bands and C band, as it is
designed for higher frequencies than the ones used by Blockstream
Satellite. However, a C band antenna will not work for Ku bands, as it is
designed for lower frequencies.

The following table summarizes the transmission bands and frequencies of the
signals broadcast by the satellites that we use:

| Satellite          | Band    | Frequency    |
|--------------------|---------|--------------|
| Galaxy 18          | Ku High | 12016.4 MHz  |
| Eutelsat 113       | Ku High | 12066.9 MHz  |
| Telstar 11N Africa | Ku Low  | 11480.7 MHz  |
| Telstar 11N Europe | Ku Low  | 11484.3 MHz  |
| Telstar 18V Ku     | Ku Low  | 11506.75 MHz |
| Telstar 18V C      | C       | 4053.83 MHz  |

